@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: vector-instances
 version: 3.3.1
-id: vector-instances-3.3.1-02e9d5a5e0f0cb8c3532624a3303c400
-key: vecto_29T3XlNRWcbE9UFYgo4Lv6
+id: vector-instances-3.3.1-5b4c30b7e00e1b44488771d2f5916bb7
+key: vecto_EakJKkxzJnfKNcEtSgW8cq
 license: BSD3
 maintainer: ekmett@gmail.com
 homepage: http://github.com/ekmett/vector-instances
@@ -17,13 +17,13 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/vector-instances-3.3.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/vector-instances-3.3.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/vector-instances-3.3.1
-hs-libraries: HSvector-instances-3.3.1-29T3XlNRWcbE9UFYgo4Lv6
+hs-libraries: HSvector-instances-3.3.1-EakJKkxzJnfKNcEtSgW8cq
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     comonad-5-e98e7adc8875accf64a86529d9aeae51
-    keys-3.11-c0312e613ec912c390e00fde3001f005
-    pointed-5-43ce6d13385073054689e0a07f00abbe
-    semigroupoids-5.0.1-7b21d348d4b507a23638386627368bec
+    keys-3.11-ade7d136d0c3ee7dfe52cac8116b48e8
+    pointed-5-863b6efa1ec5f2214ed63d015336841b
+    semigroupoids-5.0.1-53b0b3ecfca9d658a051ef7b22e11130
     semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
 haddock-interfaces: /usr/share/doc/haskell-vector-instances/html/vector-instances.haddock
